==> admob-4.4.5-sources.jar: com/yodo1/mas/mediation/admob/Yodo1MasAdMobBannerAdapter.java <==
package com.yodo1.mas.mediation.admob;

import android.app.Activity;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.View;

import com.google.ads.mediation.admob.AdMobAdapter;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.AdView;
import com.google.android.gms.ads.LoadAdError;
import com.yodo1.mas.Yodo1Mas;
import com.yodo1.mas.analytics.Yodo1MasSensorHelper;
import com.yodo1.mas.banner.Yodo1MasBannerAdSize;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.event.Yodo1MasAdEvent;
import com.yodo1.mas.helper.Yodo1MasHelper;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;
import com.yodo1.mas.mediation.Yodo1MasBannerAdapterBase;

import androidx.annotation.NonNull;

public class Yodo1MasAdMobBannerAdapter extends Yodo1MasBannerAdapterBase {

    private AdView bannerAd;

    @Override
    public boolean isBannerAdvertLoaded() {
        return bannerAd != null && !TextUtils.isEmpty(bannerAd.getAdUnitId()) && bannerState == Yodo1MasAdapterBase.AdvertState.LOADED;
    }

    @Override
    public void loadBannerAdvert(@NonNull Activity activity) {
        super.loadBannerAdvert(activity);

        Yodo1MasAdapterBase.AdId adId = getBannerAdId();
        if (adId != null && !TextUtils.isEmpty(adId.adId)) {
            if (bannerAd == null || !adId.adId.equals(bannerAd.getAdUnitId())) {
                bannerAd = new AdView(activity);
                bannerAd.setAdListener(bannerListener);
                setBannerSize(activity, bannerAd);
                bannerAd.setAdUnitId(adId.adId);
            }
            if (bannerAd != null && bannerState != Yodo1MasAdapterBase.AdvertState.LOADING) {
                String message = "method: loadBannerAdvert, loading banner ad...";
                Log.d(TAG, message);
                bannerAd.loadAd(buildRequest());
                bannerState = Yodo1MasAdapterBase.AdvertState.LOADING;
            }
        }
    }

    @Override
    public View getBannerView() {
        return bannerAd;
    }

    @Override
    public void dismissBannerAdvert(boolean destroy) {
        super.dismissBannerAdvert(destroy);
        if (bannerAd != null) {
            if (destroy) {
                bannerAd.destroy();
                bannerAd = null;
                bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
            }
        }
    }

    @Override
    public boolean isSupportMultipleInstance() {
        return true;
    }

    private AdRequest buildRequest() {
        final AdRequest.Builder builder = new AdRequest.Builder();
        final Bundle extras = new Bundle();
        if (!Yodo1MasHelper.getInstance().isGDPRUserConsent()) {
            extras.putString("npa", "1");
        }
//        if (Yodo1MasHelper.getInstance().isCOPPAAgeRestricted()) {
//            builder.tagForChildDirectedTreatment(true);
//        }
        if (Yodo1MasHelper.getInstance().isCCPADoNotSell()) {
            extras.putInt("rdp", 1);
        }
        return builder.addNetworkExtrasBundle(AdMobAdapter.class, extras).build();
    }

    private void setBannerSize(Activity activity, AdView bannerAd) {
        Yodo1MasBannerAdSize size = bannerConfig.size;
        Log.d(TAG, "setBannerSize: size: " + size.name());

        if(Yodo1MasBannerAdSize.Banner == size) {
            bannerAd.setAdSize(AdSize.BANNER);
        }
        else if(Yodo1MasBannerAdSize.LargeBanner == size) {
            bannerAd.setAdSize(AdSize.LARGE_BANNER);
        }
        else if(Yodo1MasBannerAdSize.IABMediumRectangle == size) {
            bannerAd.setAdSize(AdSize.MEDIUM_RECTANGLE);
        }
        else if(Yodo1MasBannerAdSize.SmartBanner == size) {
            bannerAd.setAdSize(AdSize.SMART_BANNER);
        }
        else if(Yodo1MasBannerAdSize.AdaptiveBanner == size) {
            bannerAd.setAdSize(getAdSize(activity));
        }

    }

    private AdSize getAdSize(Activity activity) {
        // Step 2 - Determine the screen width (less decorations) to use for the ad width.
        Display display = activity.getWindowManager().getDefaultDisplay();
        DisplayMetrics outMetrics = new DisplayMetrics();
        display.getMetrics(outMetrics);

        float widthPixels = outMetrics.widthPixels;
        float density = outMetrics.density;

        int adWidth = (int) (widthPixels / density);

        // Step 3 - Get adaptive ad size and return for setting on the ad view.
        return AdSize.getCurrentOrientationAnchoredAdaptiveBannerAdSize(activity, adWidth);
    }

    private final AdListener bannerListener = new AdListener() {

        @Override
        public void onAdOpened() {
            String message = "method: onAdOpened, banner";
            Log.d(TAG, message);
            bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
            callback(Yodo1MasAdEvent.CODE_OPENED, Yodo1Mas.AdType.Banner, TAG + ":{" + message + "}");
        }

        @Override
        public void onAdClicked() {
            String message = "method: onAdClicked, banner";
            Log.d(TAG, message);
        }

        @Override
        public void onAdClosed() {
            String message = "method: onAdClosed, banner";
            Log.d(TAG, message);
            bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
            callback(Yodo1MasAdEvent.CODE_CLOSED, Yodo1Mas.AdType.Banner, TAG + ":{" + message + "}");
            loadBannerAdvert();
        }

        @Override
        public void onAdLoaded() {
            super.onAdLoaded();
            String message = "method: onAdLoaded, banner, Mediation Adapter Class Name: " + ((bannerAd == null || bannerAd.getResponseInfo() ==  null) ? "" : bannerAd.getResponseInfo().getMediationAdapterClassName());
            Log.d(TAG, message);
            bannerState = Yodo1MasAdapterBase.AdvertState.LOADED;
            trackAdRequest(Yodo1Mas.AdType.Banner, Yodo1MasSensorHelper.AdResult.SUCCESS);
            callback(Yodo1MasAdEvent.CODE_LOADED, Yodo1Mas.AdType.Banner, TAG + ":{" + message + "}");
        }

        @Override
        public void onAdFailedToLoad(LoadAdError adError) {
            String message = "method: onAdFailedToLoad, banner, error: " + adError.toString();
            Log.d(TAG, message);
            trackAdRequest(Yodo1Mas.AdType.Banner, Yodo1MasSensorHelper.AdResult.FAIL);

            bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + message + "}");
            callback(error, Yodo1Mas.AdType.Banner);
            nextBanner();
            loadBannerAdvertDelayed();
        }
    };

}

==> admob-4.6.3-sources.jar: com/yodo1/mas/mediation/admob/Yodo1MasAdMobBannerAdapter.java <==
package com.yodo1.mas.mediation.admob;

import android.app.Activity;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.DisplayMetrics;
import android.util.Log;
import android.view.Display;
import android.view.View;

import androidx.annotation.NonNull;

import com.google.ads.mediation.admob.AdMobAdapter;
import com.google.android.gms.ads.AdListener;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.AdView;
import com.google.android.gms.ads.LoadAdError;
import com.yodo1.mas.banner.Yodo1MasBannerAdSize;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.event.Yodo1MasAdEvent;
import com.yodo1.mas.helper.Yodo1MasHelper;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;
import com.yodo1.mas.mediation.Yodo1MasBannerAdapterBase;

public class Yodo1MasAdMobBannerAdapter extends Yodo1MasBannerAdapterBase {

    private AdView bannerAd;
    private boolean isMax;
    private final AdListener bannerListener = new AdListener() {

        @Override
        public void onAdOpened() {
            String message = "method: onAdOpened, banner";
            Log.d(TAG, message);
            bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
            callback(Yodo1MasAdEvent.CODE_OPENED, TAG + ":{" + message + "}");
        }

        @Override
        public void onAdClicked() {
            String message = "method: onAdClicked, banner";
            Log.d(TAG, message);
        }

        @Override
        public void onAdClosed() {
            String message = "method: onAdClosed, banner";
            Log.d(TAG, message);
            bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
            callback(Yodo1MasAdEvent.CODE_CLOSED, TAG + ":{" + message + "}");
            loadBannerAdvert();
        }

        @Override
        public void onAdLoaded() {
            super.onAdLoaded();
            String message = "method: onAdLoaded, banner, Mediation Adapter Class Name: " + ((bannerAd == null || bannerAd.getResponseInfo() == null) ? "" : bannerAd.getResponseInfo().getMediationAdapterClassName());
            Log.d(TAG, message);
            bannerState = Yodo1MasAdapterBase.AdvertState.LOADED;
            advertAdapterState = AdvertAdapterState.LOADED;
            trackAdRequestSuccessed();
            callback(Yodo1MasAdEvent.CODE_LOADED, TAG + ":{" + message + "}");
            callbackAdapterState();
        }

        @Override
        public void onAdFailedToLoad(LoadAdError adError) {
            String message = "method: onAdFailedToLoad, banner, error: " + adError.toString();
            Log.d(TAG, message);
            trackAdRequestFailed(adError.getCode(), adError.getMessage());

            bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
            if (isMax()) {
                handleLoadFailedCallback(message);
                nextBanner();
                loadBannerAdvertDelayed();
            } else if (isLastPlacement()) {
                handleLoadFailedCallback(message);
            } else {
                nextBanner();
                loadBannerAdvertDelayed();
            }
        }
    };

    @Override
    public boolean isMax() {
        return isMax;
    }

    public void setMax(boolean max) {
        isMax = max;
    }

    @Override
    public boolean isBannerAdvertLoaded() {
        return bannerAd != null && !TextUtils.isEmpty(bannerAd.getAdUnitId()) && bannerState == Yodo1MasAdapterBase.AdvertState.LOADED;
    }

    @Override
    public void loadBannerAdvert(@NonNull Activity activity) {
        super.loadBannerAdvert(activity);

        Yodo1MasAdapterBase.AdId adId = getBannerAdId();
        if (!isMax() && adId != null && adId.object != null && !isPriceValuable(adId)) {
            handlePricyNotAbaliable();
            return;
        }
        if (adId != null && !TextUtils.isEmpty(adId.adId)) {
            if (bannerAd == null || !adId.adId.equals(bannerAd.getAdUnitId())) {
                bannerAd = new AdView(activity);
                bannerAd.setAdListener(bannerListener);
                setBannerSize(activity, bannerAd);
                bannerAd.setAdUnitId(adId.adId);
            }
            if (bannerAd != null && bannerState != Yodo1MasAdapterBase.AdvertState.LOADING) {
                String message = "method: loadBannerAdvert, loading banner ad...";
                Log.d(TAG, message);
                bannerAd.loadAd(buildRequest());
                bannerState = Yodo1MasAdapterBase.AdvertState.LOADING;
                advertAdapterState = AdvertAdapterState.LOADING;
                logAdIdInfo(adId);
            }
        }
    }

    @Override
    public View getBannerView() {
        return bannerAd;
    }

    @Override
    public void dismissBannerAdvert(boolean destroy) {
        super.dismissBannerAdvert(destroy);
        if (bannerAd != null) {
            if (destroy) {
                bannerAd.destroy();
                bannerAd = null;
                bannerState = Yodo1MasAdapterBase.AdvertState.NONE;
                advertAdapterState = AdvertAdapterState.NONE;
            }
        }
    }

    @Override
    public boolean isSupportMultipleInstance() {
        return true;
    }

    private AdRequest buildRequest() {
        final AdRequest.Builder builder = new AdRequest.Builder();
        final Bundle extras = new Bundle();
        if (!Yodo1MasHelper.getInstance().isGDPRUserConsent()) {
            extras.putString("npa", "1");
        }
//        if (Yodo1MasHelper.getInstance().isCOPPAAgeRestricted()) {
//            builder.tagForChildDirectedTreatment(true);
//        }
        if (Yodo1MasHelper.getInstance().isCCPADoNotSell()) {
            extras.putInt("rdp", 1);
        }
        return builder.addNetworkExtrasBundle(AdMobAdapter.class, extras).build();
    }

    private void setBannerSize(Activity activity, AdView bannerAd) {
        Yodo1MasBannerAdSize size = bannerConfig.size;
        Log.d(TAG, "setBannerSize: size: " + size.name());

        if (Yodo1MasBannerAdSize.Banner == size) {
            bannerAd.setAdSize(AdSize.BANNER);
        } else if (Yodo1MasBannerAdSize.LargeBanner == size) {
            bannerAd.setAdSize(AdSize.LARGE_BANNER);
        } else if (Yodo1MasBannerAdSize.IABMediumRectangle == size) {
            bannerAd.setAdSize(AdSize.MEDIUM_RECTANGLE);
        } else if (Yodo1MasBannerAdSize.SmartBanner == size) {
            bannerAd.setAdSize(AdSize.SMART_BANNER);
        } else if (Yodo1MasBannerAdSize.AdaptiveBanner == size) {
            bannerAd.setAdSize(getAdSize(activity));
        }

    }

    private AdSize getAdSize(Activity activity) {
        // Step 2 - Determine the screen width (less decorations) to use for the ad width.
        Display display = activity.getWindowManager().getDefaultDisplay();
        DisplayMetrics outMetrics = new DisplayMetrics();
        display.getMetrics(outMetrics);

        float widthPixels = outMetrics.widthPixels;
        float density = outMetrics.density;

        int adWidth = (int) (widthPixels / density);

        // Step 3 - Get adaptive ad size and return for setting on the ad view.
        return AdSize.getCurrentOrientationAnchoredAdaptiveBannerAdSize(activity, adWidth);
    }

    private void handleLoadFailedCallback(String message) {
        Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + message + "}");
        callback(error);
        advertAdapterState = AdvertAdapterState.FAILED;
        callbackAdapterState();
    }


}
